@@ -3,10 +3,9 @@
 A terminal command executor module
 """
 __author__ = 'Alisue <lambdalisue@hashnote.net>'
-
+import io
 import sys
 import subprocess
-import StringIO
 
 def call(args):
     """
@@ -23,10 +22,10 @@ def call(args):
         exit_code indicate the exit code of the command and stdout indicate the
         output of the command
     """
-    b = StringIO.StringIO()
+    b = io.BytesIO()
     p = subprocess.Popen(args,
-                            stdout=subprocess.PIPE,
-                            stderr=subprocess.STDOUT)
+                         stdout=subprocess.PIPE,
+                         stderr=subprocess.STDOUT)
     while p.returncode is None:
         stdout = p.communicate()[0]
         # output to stdout and buffer
